ProblemBuilder

Struct ProblemBuilder 

pub struct ProblemBuilder<'a, E, DU, IU, DC, IC, C> { /* private fields */ }
Problem builder

The ProblemBuilder allows us to build a Problem from known inputs and uncertainties.

Implementations

Source

impl<'a, E: Float> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, Unset>

pub fn new<V: Into<ArrayView1<'a, E>>>( independent: V, dependent: V, ) -> Result<Self, PolyCalError<E>>

Create a new ProblemBuilder from independent and dependent data.

Errors
  • If the independent and dependent data provided contain unequal numbers of observations.
  • If the independent and dependent data provided contain NaN or infinity
Source

impl<E, DU, IU, DC, IC, C> ProblemBuilder<'_, E, DU, IU, DC, IC, C>

pub const fn with_scoring_strategy( self, scoring_strategy: ScoringStrategy, ) -> Self

Attach a scoring strategy.

Source

impl<'a, E: Float, C> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, C>

pub fn with_dependent_variance( self, dependent_variance: impl Into<ArrayView1<'a, E>>, ) -> Result<ProblemBuilder<'a, E, Set, Unset, Unset, Unset, C>, PolyCalError<E>>

Attach a variance for the dependent variable

Errors
  • If the provided values contain any NaN, infinite, or zero values. Note that zeros are not allowed, because the weighted least squares process relies on the inverse of the variance
Source

impl<'a, E: Float, C> ProblemBuilder<'a, E, Unset, Set, Unset, Unset, C>

pub fn with_dependent_variance( self, dependent_variance: impl Into<ArrayView1<'a, E>>, ) -> Result<ProblemBuilder<'a, E, Set, Set, Unset, Unset, C>, PolyCalError<E>>

Attach a variance for the dependent variable

Errors
  • If the provided values contain any NaN, infinite, or zero values. Note that zeros are not allowed, because the weighted least squares process relies on the inverse of the variance
Source

impl<'a, E, DU, IU, DC, IC> ProblemBuilder<'a, E, DU, IU, DC, IC, Unset>

pub const fn with_constraint<C>( self, constraint: C, ) -> ProblemBuilder<'a, E, DU, IU, DC, IC, C>

Source

impl<'a, E: PartialOrd + Scalar> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, Unset>

pub fn build(self) -> Problem<'a, E>

Source

impl<'a, E: PartialOrd + Scalar> ProblemBuilder<'a, E, Set, Unset, Unset, Unset, Unset>

pub fn build(self) -> Problem<'a, E>

Build a problem

Panics

The function should not panic, the typestate prevents an invalid state, ensuring the unwrap is Ok

Source

impl<'a, E: PartialOrd + Scalar, C: Into<Constraint<E>>> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, C>

pub fn build(self) -> Problem<'a, E>

Source

impl<'a, E: PartialOrd + Scalar, C: Into<Constraint<E>>> ProblemBuilder<'a, E, Set, Unset, Unset, Unset, C>

pub fn build(self) -> Problem<'a, E>

Build a problem

Panics

The function should not panic, the typestate prevents an invalid state, ensuring the unwrap is Ok