pub struct ProblemBuilder<'a, E, DU, IU, DC, IC, C> { /* private fields */ }Expand description
Problem builder
The ProblemBuilder allows us to build a Problem from known inputs
and uncertainties.
Implementations
Sourceimpl<'a, E: Float> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, Unset>
impl<'a, E: Float> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, Unset>
Sourcepub fn new<V: Into<ArrayView1<'a, E>>>(
independent: V,
dependent: V,
) -> Result<Self, PolyCalError<E>>
pub fn new<V: Into<ArrayView1<'a, E>>>( independent: V, dependent: V, ) -> Result<Self, PolyCalError<E>>
Create a new ProblemBuilder from independent and dependent data.
Errors
- If the independent and dependent data provided contain unequal numbers of observations.
- If the independent and dependent data provided contain NaN or infinity
Sourceimpl<E, DU, IU, DC, IC, C> ProblemBuilder<'_, E, DU, IU, DC, IC, C>
impl<E, DU, IU, DC, IC, C> ProblemBuilder<'_, E, DU, IU, DC, IC, C>
Sourcepub const fn with_scoring_strategy(
self,
scoring_strategy: ScoringStrategy,
) -> Self
pub const fn with_scoring_strategy( self, scoring_strategy: ScoringStrategy, ) -> Self
Attach a scoring strategy.
Sourceimpl<'a, E: Float, C> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, C>
impl<'a, E: Float, C> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, C>
Sourcepub fn with_dependent_variance(
self,
dependent_variance: impl Into<ArrayView1<'a, E>>,
) -> Result<ProblemBuilder<'a, E, Set, Unset, Unset, Unset, C>, PolyCalError<E>>
pub fn with_dependent_variance( self, dependent_variance: impl Into<ArrayView1<'a, E>>, ) -> Result<ProblemBuilder<'a, E, Set, Unset, Unset, Unset, C>, PolyCalError<E>>
Attach a variance for the dependent variable
Errors
- If the provided values contain any NaN, infinite, or zero values. Note that zeros are not allowed, because the weighted least squares process relies on the inverse of the variance
Sourceimpl<'a, E: Float, C> ProblemBuilder<'a, E, Unset, Set, Unset, Unset, C>
impl<'a, E: Float, C> ProblemBuilder<'a, E, Unset, Set, Unset, Unset, C>
Sourcepub fn with_dependent_variance(
self,
dependent_variance: impl Into<ArrayView1<'a, E>>,
) -> Result<ProblemBuilder<'a, E, Set, Set, Unset, Unset, C>, PolyCalError<E>>
pub fn with_dependent_variance( self, dependent_variance: impl Into<ArrayView1<'a, E>>, ) -> Result<ProblemBuilder<'a, E, Set, Set, Unset, Unset, C>, PolyCalError<E>>
Attach a variance for the dependent variable
Errors
- If the provided values contain any NaN, infinite, or zero values. Note that zeros are not allowed, because the weighted least squares process relies on the inverse of the variance
Sourceimpl<'a, E, DU, IU, DC, IC> ProblemBuilder<'a, E, DU, IU, DC, IC, Unset>
impl<'a, E, DU, IU, DC, IC> ProblemBuilder<'a, E, DU, IU, DC, IC, Unset>
pub const fn with_constraint<C>( self, constraint: C, ) -> ProblemBuilder<'a, E, DU, IU, DC, IC, C>
Sourceimpl<'a, E: PartialOrd + Scalar> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, Unset>
impl<'a, E: PartialOrd + Scalar> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, Unset>
Sourceimpl<'a, E: PartialOrd + Scalar> ProblemBuilder<'a, E, Set, Unset, Unset, Unset, Unset>
impl<'a, E: PartialOrd + Scalar> ProblemBuilder<'a, E, Set, Unset, Unset, Unset, Unset>
Sourceimpl<'a, E: PartialOrd + Scalar, C: Into<Constraint<E>>> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, C>
impl<'a, E: PartialOrd + Scalar, C: Into<Constraint<E>>> ProblemBuilder<'a, E, Unset, Unset, Unset, Unset, C>
Sourceimpl<'a, E: PartialOrd + Scalar, C: Into<Constraint<E>>> ProblemBuilder<'a, E, Set, Unset, Unset, Unset, C>
impl<'a, E: PartialOrd + Scalar, C: Into<Constraint<E>>> ProblemBuilder<'a, E, Set, Unset, Unset, Unset, C>